@@ -129,7 +129,7 @@ class Saera:
 
 		self.mod = Popen(['python', '/opt/modrana/modrana.py', '--return-current-coordinates'], stdout=PIPE, bufsize=1, close_fds=ON_POSIX)
 		self.q = Queue()
-		self.t = Thread(target=enqueue_output, args=(self.mod.stdout, q.self))
+		self.t = Thread(target=enqueue_output, args=(self.mod.stdout, self.q))
 		self.t.daemon = True # thread dies with the program
 		self.t.start()
 
