@@ -313,7 +313,12 @@ def gas(input):
 
 def get_weather(input):
 	try:
-		f = urllib2.urlopen('http://api.wunderground.com/api/0a02b434d9bf118f/geolookup/conditions/q/NY/New_York.json')
+		if location:
+			loc = ','.join(location.split(',')[:2])
+		else:
+			loc = 'NY/New_York'
+		# f = urllib2.urlopen('http://api.wunderground.com/api/0a02b434d9bf118f/geolookup/conditions/q/NY/New_York.json')
+		f = urllib2.urlopen('http://api.wunderground.com/api/0a02b434d9bf118f/geolookup/conditions/q/'+loc+'.json')
 	except urllib2.URLError:
 		return "I need an internet connection to look up the weather, sorry."
 	json_string = f.read()
