@@ -91,4 +91,13 @@ food = ['pizza', 'pasta', 'sushi', 'falafel', 'bagels', 'burger', 'veggie burger
 
 # General yes/no
 affirmative = ['affirmative', 'absolutely', 'all right', 'aye', 'by all means', 'certainly', 'definitely', 'exactly', 'fine', 'indubitably', 'naturally', 'of course', 'okay', 'positively', 'precisely', 'sure thing', 'sure', 'undoubtedly', 'unquestionably', 'very well', 'yeah', 'yep']
-negative = ['absolutely not', 'by no means', 'negative', 'never', 'no way', 'not at all', 'not by any means']
\ No newline at end of file
+negative = ['absolutely not', 'by no means', 'negative', 'never', 'no way', 'not at all', 'not by any means']
+
+# Chuck Norris facts
+chuck_norris = ['Chuck Norris does not sleep. He waits.',
+				"Chuck Norris doesn't read books. He stares them down until he gets the information he wants.",
+				'When the Boogeyman goes to sleep every night he checks his closet for Chuck Norris.',
+				"Chuck Norris has already been to Mars; that's why there are no signs of life there.",
+				"Chuck Norris doesn't call the wrong number. You answer the wrong phone.",
+				"When Chuck Norris does a pushup, he isn't lifting himself up, he's pushing the Earth down.",
+				"Chuck Norris does not get frostbite. Chuck Norris bites frost."]
